
<img src="https://raw.githubusercontent.com/NationalSecurityAgency/ghidra/master/Ghidra/Features/Base/src/main/resources/images/GHIDRA_3.png" width="400">

<hr>

The Official Ghidra Python Interface is currently under development.